Cracking the Sitcom Code - The Atlantic
Description: After signing up to write a script for Croatian television, I learned that virtually all TV comedies, from Seinfeld to South Park, follow a simple formula.

TheAtlantic.com
Continue ()
Advertisement

# The Atlantic

Subscribe Now
Get The Atlantic on Facebook

- ## What's Wrong With Georgia?

  By Alana Semuels

- ## Readability Is a Myth

  By Noah Berlatsky

- ## The Imitation Game: A Smart Person's Fantasy

  By Emma Green

- ## The Internet Cannot Create Social Change

  By Kentaro Toyama

# Cracking the Sitcom Code

After signing up to write a script for Croatian television, I learned that virtually all TV comedies, from Seinfeld to South Park, follow a simple formula.
Noah Charney Dec 28 2014, 8:01 AM ET

- Share on Facebook
- Twitter
- LinkedIn
- Email
- Print
- Comments

NBC

As happens to so many of us, I was asked to write a sitcom for Croatian television. I’m an American ex-pat living in Slovenia, and I know next to nothing about Croatia, besides the fact that it’s Slovenia’s southern neighbor, a fellow ex-Yugoslav republic, and that the language resembles Slovene except with a lot more “js” in it. I am a writer of books and articles, and I used to write a lot of plays, but I’ve never written for television. So I immediately said, “Sure, of course I can do that,” before rushing off to Google “How to write a sitcom.”

In addition to much Googling, I spent a good deal of time watching sitcoms. I was after tips on how they are constructed, and watched actively, looking to crack open their laugh-tracked shiny exterior to get at the goopy mechanism within, to see how they functioned. What I found out surprised me, and changed the way that I watch television.

#### Related Story

The One Where I Counted the Jokes in Popular Sitcoms

From The Simpsons to Seinfeld, from Everybody Loves Raymond to Everybody Hates Chris, from Taxi to Arrested Development to Parks & Recreation, there is a highly-specific, minute-by-minute recipe used to write the vast majority of sitcoms out there. And once you know the formula, it makes it much easier to write them, and much harder to watch them without seeing that formula—the “sitcom code”—everywhere you look.

My giddy-panicked Googling actually produced fruitful results. With little idea as to where I should begin, I turned to the confidence-inspiring blog, Wise Sloth (whose author, like me, has no TV writing experience), which provided a 15-page breakdown of sitcom formats that I used as a point of departure for my own study. And by study, I mean hopping into my pajamas, cuddling up to my Peruvian Hairless, and watching TV with a notebook in hand. Talib Visram recently wrote in The Atlantic about his experience counting jokes per minute in popular TV shows. My approach was more deconstructionist, and directly applicable to my new gig. I had to figure out how such shows were built, and fast.

Fortunately, the answer presented itself very quickly.

First of all, word-processing programs often come with screenwriting templates. FinalDraft, the most popular software for those penning scripts, even has a Sitcom Template, which of course makes life much easier. But as for how to construct an episode, various bloggers, from the Wise Sloth to helpful folks at the BBC, noted a basic structure that I immediately recognized in every sitcom episode I tested. This structure is so formulaic that you’d think it would suck the fun out of writing and watching such shows, but it does nothing of the sort. While knowing the code it changes the way I watch TV, it only increases my admiration for the good writers who do so much within relatively strict confines.

To demonstrate how this formula works, I’ve chosen an episode of a favorite show, somewhat at random, because it ideally exemplifies the template: episode 4 of season 1 of Parks & Recreation.

The Sitcom Code breaks down what needs to happen in each episode, by the minute. As Dan Richter of Demand Media notes, “Sitcoms, minus commercials, are typically 22 minutes long [with] a script of 25-40 pages. Every sitcom episode has a main plot (story A), as well as one or two subplots (stories B and C).” There are three main acts, divided by two commercial breaks (in most American TV), with 3-5 scenes per act. One of the distinguishing characteristics of sitcoms, as opposed to other forms of television, is that the main protagonist(s) barely change from one episode to the next, let alone from season to season (Maggie Simpson has been sucking on a pacifier for nearly thirty years). Therefore whatever happens in the episode, the situation must end largely where it began. The Wise Sloth points out that 22 minutes is “not even really time enough to tell a full story. The whole story has to be on fast-forward,” so simplification is key.

Poet Philip Larkin described all plots as “a beginning, a muddle, and an end,” which is as good a description as any. Each episode begins with the protagonist stating a goal or problem that must be solved, and which we understand will be solved by the end of the episode. If the problem is solved too quickly, then the episode won’t stretch out to 22 minutes, so the first attempt at reaching the goal or solving the problem must fail (“the muddle”), requiring a new approach, before the episode ends and the protagonist either does, or does not, achieve what they set out to do. The goal might be Homer trying to make a fortune by selling recycled grease in The Simpsons, or Job Bluth setting out to sabotage the family’s banana stand in Arrested Development, or the Seinfeld crew looking for where they parked in a vast lot. Another hallmark of sitcoms is that the protagonists frequently fail, and we often want them to, because we do not want our favorite characters to change too much. If Leslie Knope ever left Pawnee for a career as a DC politician, we would be distraught. If Kramer got married and moved to the suburbs—whoa, now!

When writers sit around and prepare a new episode, many literally map out what will happen, minute-by-minute, in the main storyline and sub-storylines, filling in jokes later. Let’s see how this played out in the Parks & Recreation episode, “Boys' Club.”

- 1
- 2
- 3
- > >
- Single Page

Presented by
Jump to Comments

- Share on Facebook
- Twitter
- LinkedIn
- Reddit
- Email
- Print
- Comments

Noah Charney is an author and art historian. He has written for Esquire, The Guardian, The Daily Beast, and CNN.

- All Posts

##

More video

### The Pentagon's $1.5 Trillion Mistake

The F-35 fighter jet was supposed to do everything. Instead, it can barely do anything.

- Share on Facebook
- Twitter

More Articles

### The Internet Cannot Create Social Change

## Join the Discussion

After you comment, click Post. If you’re not already logged in you will be asked to log in or register.

blog comments powered by Disqus
Close

## Video

### The Pentagon's $1.5 Trillion Mistake

The F-35 fighter jet was supposed to do everything. Instead, it can barely do anything.

## Video

### How to Cook Spaghetti Squash (and Why)

Cooking for yourself is one of the surest ways to eat well.

## Video

### Before Tinder, a Tree

Looking for your soulmate? Write a letter to the "Bridegroom's Oak" in Germany.

## Video

### Where High Tech Meets the 1950s

Why did Green Bank, West Virginia, ban wireless signals? For science.

## Video

### Would You Live in a Treehouse?

A treehouse can be an ideal office space, vacation rental, and way of reconnecting with your youth.

## More in Entertainment

- ### The Imitation Game: A Smart Person's Fantasy

  Emma Green

- ### Readability Is a Myth

  Noah Berlatsky

- ### A Design Magazine That's More Than Just Pretty

  Steven Heller

## In Focus

### 2015: Ringing in the New Year

## Just In

- ### Why Would Anybody Adopt the Euro in 2015?

  Adam Chandler

- ### In Partial Defense of Lee Greenwood's Grammatically Challenged 'God Bless the U.S.A.'

  Jeffrey Goldberg

- ### Human Traffickers Are Abandoning Boats Full of Migrants

  Adam Chandler

## Most Popular

1
  The Tragedy of the American Military
2
  What's Wrong With Georgia?
3
  The Death of the Artist—and the Birth of the Creative Entrepreneur
4
  Readability Is a Myth
5
  All the Single Ladies
6
  The Future of Getting Arrested
7
  What U.S. Intelligence Predicted the World Would Look Like in 2015
8
  The Imitation Game: A Smart Person's Fantasy
9
  A Hacker's Hit List of American Infrastructure
10
  The Benefits of Fewer NYPD Arrests

Powered by the Parse.ly Publisher Platform (P3).